var fs=require('fs');
var java = require('java');
var jvm=java;
var logger = require('winston');

var loadJava=function(path){
    fs.readdir(path, function(err, files) { 
         files.forEach(function(filename) {
                fs.stat(path +"/"+ filename, function(err, stats) {
                    if (!err) {
                        if(stats.isDirectory()){
                            loadJava(path+"/"+filename);
                        }else{
                            if(filename.endsWith(".jar")){
                                 logger.info("Load Java .jar :: "+ filename);
                                 jvm.classpath.push(path+"/"+filename);
                            }
                        }
                    }
                });
        });
    });
};

exports.loadJava=loadJava;
exports.jvm=jvm;